@@ -4,12 +4,11 @@ package Dancer2::Plugin::Path::Class;
 
 use strict;
 use warnings;
-use 5.010001;
 
-our $VERSION = 0.02;
+our $VERSION = 0.04;
 
 use Dancer2::Plugin;
-use Dancer2::Core::MIME;
+use MIME::Types;
 use Path::Class;
 use Fcntl "S_IRUSR";
 use Format::Human::Bytes;
@@ -50,15 +49,17 @@ sub _ymd {
 }
 
 sub _decorate_files {
-    my ($dsl, $dir, $files) = @_;
+    my ($dir, $files) = @_;
     my @ls_files = ();
+    my $mt = MIME::Types->new;
     for my $basename (@{$files}) {
         my $st = $dir->file($basename)->stat;
         next unless $st;
         next unless $st->cando(S_IRUSR, 1); # can read
+        my $type = $mt->mimeTypeOf($basename);
         push @ls_files, {
             name => $basename,
-            type => $dsl->mime->for_file($basename),
+            type => "$type",
             size => Format::Human::Bytes::base2($st->size),
             date => _ymd($st->mtime),
         };
@@ -90,10 +91,10 @@ register ls => sub {
         @dirs = sort {$a cmp $b} @dirs;
         $ls_dirs = _decorate_dirs($dir, \@dirs);
         @files = sort {$a cmp $b} @files;
-        $ls_files = _decorate_files($dsl, $dir, \@files);
+        $ls_files = _decorate_files($dir, \@files);
     } else {
         push @files, $dir->basename;
-        $ls_files = _decorate_files($dsl, $dir->parent, \@files);
+        $ls_files = _decorate_files($dir->parent, \@files);
     }
 
     my $ls_cdup = $dsl->request->path;
@@ -119,21 +120,21 @@ Dancer2::Plugin::Path::Class - list a directory using Path::Class
 
 =head1 VERSION
 
-version 0.02
+version 0.04
 
 =head1 SYNOPSIS
 
   use Dancer2::Plugin::Path::Class;
   
   get '/img' => sub {
-      my $dir = ls(config->{public_dir}, '/img');
+      my $dir = ls(config->{public}, '/img');
       template 'dirlisting';
   };
   
   get '/img/**' => sub {
       my ($path) = splat;
       my @splat = @{$path};
-      my $dir = ls(config->{public_dir}, '/img', @splat);
+      my $dir = ls(config->{public}, '/img', @splat);
       return template 'dirlisting' if -d $dir;
       send_file("$dir", system_path =>1);
   };
@@ -183,6 +184,10 @@ or ending with a tilde ('~') are ignored.
 
 Henk van Oers, HVOERS@cpan.org
 
+=head1 CONTRIBUTORS
+
+    Peter Mottram
+
 =head1 COPYRIGHT and LICENSE
 
 Copyright (c) Henk van Oers.  All rights reserved.
